@@ -3,13 +3,14 @@
 # 3rd step: deterministic match
 # 4th step: aggregate
 
-match_weighted_cases_probabilistic <- function( # nocov start
+match_weighted_cases_probabilistic <- function(
+  # nocov start
   con = con,
   x = 'input_padrao_db',
   output_tb = "output_db",
   key_cols = key_cols,
   match_type = match_type,
-  resultado_completo){
+  resultado_completo) {
 
   # match_type = "pn01"
 
@@ -21,26 +22,21 @@ match_weighted_cases_probabilistic <- function( # nocov start
   # write cnefe table to db
   register_cnefe_table(con, match_type)
 
-
-
   # 1st step: create small table with unique logradouros -----------------------
   unique_logradouros_tbl <- register_unique_logradouros_table(con, match_type)
 
-
   # 2nd step: update input_padrao_db with the most probable logradouro ---------
-
   calculate_string_dist(con, match_type, unique_logradouros_tbl)
 
-
   # 3rd step: match deterministico --------------------------------------------------------
 
   # cols that cannot be null
-  cols_not_null <-  paste(
+  cols_not_null <- paste(
     glue::glue("{x}.{key_cols} IS NOT NULL"),
     collapse = ' AND '
   )
 
-  key_cols <- key_cols[ key_cols != 'numero']
+  key_cols <- key_cols[key_cols != 'numero']
 
   # Create the JOIN condition by concatenating the key columns
   join_condition_determ <- paste(
@@ -56,8 +52,11 @@ match_weighted_cases_probabilistic <- function( # nocov start
   )
 
   # cols that cannot be null
-  cols_not_null_match <- gsub('.logradouro', '.temp_lograd_determ', cols_not_null)
-  cols_not_null_match <- paste("AND ", cols_not_null_match)
+  cols_not_null_match <- gsub(
+    '.logradouro',
+    '.temp_lograd_determ',
+    cols_not_null
+  )
 
   # whether to keep all columns in the result
   colunas_encontradas <- ""
@@ -65,36 +64,54 @@ match_weighted_cases_probabilistic <- function( # nocov start
   additional_cols_second <- ""
 
   if (isTRUE(resultado_completo)) {
-
     colunas_encontradas <- paste0(
       glue::glue("{key_cols}_encontrado"),
-      collapse = ', ')
+      collapse = ', '
+    )
 
-    colunas_encontradas <- gsub('localidade_encontrado', 'localidade_encontrada', colunas_encontradas)
+    colunas_encontradas <- gsub(
+      'localidade_encontrado',
+      'localidade_encontrada',
+      colunas_encontradas
+    )
     colunas_encontradas <- paste0(", ", colunas_encontradas)
 
     # additonal cols for the first part of the query
     additional_cols_first <- paste0(
       glue::glue("{y}.{key_cols} AS {key_cols}_encontrado"),
-      collapse = ', ')
-    additional_cols_first <- gsub('localidade_encontrado', 'localidade_encontrada', additional_cols_first)
+      collapse = ', '
+    )
+    additional_cols_first <- gsub(
+      'localidade_encontrado',
+      'localidade_encontrada',
+      additional_cols_first
+    )
     additional_cols_first <- paste0(", ", additional_cols_first)
 
     # additonal cols for the second part of the query
     additional_cols_second <- paste0(
       glue::glue("FIRST({key_cols}_encontrado) AS {key_cols}_encontrado"),
-      collapse = ', ')
-    additional_cols_second <- gsub('localidade_encontrado', 'localidade_encontrada', additional_cols_second)
+      collapse = ', '
+    )
+    additional_cols_second <- gsub(
+      'localidade_encontrado',
+      'localidade_encontrada',
+      additional_cols_second
+    )
     additional_cols_second <- paste0(", ", additional_cols_second)
 
+    # adiciona codigo do setor censitario
+    additional_cols_first <- paste0(additional_cols_first, glue::glue(", {y}.cod_setor AS cod_setor"))
+    additional_cols_second <- paste0(additional_cols_second, glue::glue(", FIRST(cod_setor)"))
+    colunas_encontradas <- paste0(colunas_encontradas, ", cod_setor")
+
   }
 
   # Match query  --------------------------------------------------------
 
-
   query_match <- glue::glue(
     "
-  -- PART 1) left join to get all cases that match
+  -- PART 1) inner join to get all cases that match
   WITH temp_db AS (
       SELECT {x}.tempidgeocodebr,
              {x}.numero,
@@ -106,9 +123,9 @@ match_weighted_cases_probabilistic <- function( # nocov start
              {x}.log_causa_confusao,
              {y}.n_casos AS contagem_cnefe {additional_cols_first}
           FROM {x}
-          LEFT JOIN {y}
+          INNER JOIN {y}
           ON {join_condition_determ}
-          WHERE lon IS NOT NULL {cols_not_null_match}
+          WHERE {cols_not_null_match}
           )
 
   -- PART 2: aggregate and interpolate get aprox location
@@ -128,15 +145,11 @@ match_weighted_cases_probabilistic <- function( # nocov start
       GROUP BY tempidgeocodebr, endereco_encontrado;"
   )
 
-
   DBI::dbExecute(con, query_match)
   # DBI::dbExecute(con, query_aggregate)
   # d <- DBI::dbReadTable(con, 'output_db')
   # d <- DBI::dbReadTable(con, 'aaa')
 
-
-
-
   # UPDATE input_padrao_db: Remove observations found in previous step
   temp_n <- update_input_db(
     con,
